<!-- K: navigate -->
<!-- S: Plan a route and determine your location. -->

This chapter covers navigation techniques and tools.

## Be prepared
<!-- K: prepare, gear, knowledge, skill, map, compass, flashlight, gps -->
<!-- S: Bring a map, compass, and flashlight. Learn how to navigate with a map and compass and plan routes. -->

### Gear
**Necessities**:
- Map
- Compass
- Flashlight/headlamp

**Optional**:
- GPS device

### Knowledge and skills
Start by learning how to do the following:
- Navigate with a map and compass.
- Plan a route.
- Set declination on a compass.
- Determine your location on a map.
- Measure distances on a map.
- Read a topographic map.

Once you have mastered these skills, you should learn how to do the following:
- Use a GPS device for navigation.
- Utilize advanced navigation techniques, like using the sun and stars.
- Take a detour.

## Route planning
<!-- K: route, plan, trip, detour -->
<!-- S: Plan your route to avoid getting lost and ensure you reach your destination safely. -->

Plan your route to avoid getting lost and ensure you reach your destination safely. Consider the following factors when planning your route:
- Choose a route that matches your skill level and fitness. Use the contour lines on a map to gauge the terrain difficulty.
- Identify landmarks along the way to help you stay on track.
- Plan for rest stops and water sources.
- Identify alternative routes in case of obstacles or emergencies.
- Share your route with someone who can alert authorities if you don't return on time.
- If you need to detour, mark your new route on the map and adjust your bearings accordingly.

## Movement
<!-- K: move, terrain, mountain, cold, desert, jungle, night, river, cross -->
<!-- S: Move carefully and adapt to the terrain. Avoid following animal trails. -->

- If you are lost, staying put and waiting for rescue is typically best.
- Keep your body weight balanced over your feet.
- Use zigzag paths on steep slopes and maintain a bend in your knees when descending to protect your joints.
- Take breaks to rest and rehydrate.
- Be cautious of animal trails, which may lead to resources like water but can also get you lost.

### Terrain considerations

**Mountainous/cold**:

- Avoid areas prone to avalanches and be cautious when crossing snow-covered slopes.
- Acclimate to high altitudes to avoid symptoms like headaches, nausea, and fatigue.
- Use snowshoes or skis for easier travel in snowy conditions. Test ice and snow conditions with a pole or stick before stepping.
- Avoid walking on frozen bodies of water unless you know the ice thickness.

**Desert**:

- Conserve water by traveling during cooler hours and wearing appropriate clothing to reduce sweating.
- Avoid salt marshes.
- Prepare for the drastic temperature shifts between day and night.
- Protect electronic devices from extreme heat and direct sunlight.
- Stick to the shadows to avoid direct sun exposure and reduce the risk of heat exhaustion.
- Distance can be deceiving in the desert (paths often look shorter than they are); plan your route carefully and carry enough water and supplies.

**Jungle**:

- It will be harder to find you under a dense canopy.
- Move with the vegetation rather than fighting against it to conserve energy.
- Focus on distant landmarks rather than near objects to maintain direction.
- Wear protective clothing to avoid insect bites and stings.
- Treat any wounds and scratches promptly to avoid infection.

**Night**:

- Use a flashlight or headlamp to illuminate your path.
- Move slowly and carefully to avoid tripping or getting lost.
- Stay on established paths or trails to reduce the risk of getting lost.
- Listen for sounds that can help you identify your surroundings, such as running water or roadways.

**Rivers and streams**:

- If you need to cross:
  - Look for the narrowest part or a place where it breaks into several channels.
  - Prefer crossing on bridges, fallen trees, or rocks. Watch out for slippery or loose surfaces.
  - Do not cross areas with strong currents or near ledges.
  - Unbuckle your pack and carry it in front of you to avoid being pulled under by its weight.
- In dire situations, following a river downstream may lead to civilization.

## Trail markers
<!-- K: trail, blaze, marker, cairn, sign, pile, block, stack, paint, flag -->
<!-- S: Trail markers help you to stay on the trail. -->

Trail markers indicate where the trail is and distinguish one trail from another. Many ways are used to mark trails, but there is no universal standard.

### Blazes
Blazes are painted symbols on trees or rocks. Typically, they are rectangles, squares, circles, triangles, or crosses. In most places, each trail is painted with a different color and/or shape of blaze.

Some blazes may also indicate the trail's direction, but this may not apply everywhere.

![](file:///android_asset/survival_guide/trail_blazes.webp)

1. **Two blazes, top blaze to the left**: Continue to the left
2. **Two blazes, top blaze to the right**: Continue to the right
3. **One blaze**: Continue straight

If a trail is new, it may have small plastic strips or flags tied to a tree instead of a blaze.

While not always true, the color and/or shape of the blazes should match what appears on a map, except that white blazes are typically black on a map.

### Cairns
Cairns are piles of rocks, typically used in places without large trees to blaze. Cairns are usually placed on the side of the trail, and you should be able to see multiple cairns at a time.

In some places, cairns may be small stacks of stones (typically 3) and could be hard to locate.

### Signs
Trail signs provide information about which trail you are on, distance/direction to points of interest, or offer general information/alerts. Always read and abide by trail signs.

### Blockers
In some places, downed trees or debris are intentionally placed in front of a path to indicate it should not be used.

## GPS
<!-- K: gps, satellite, device, location, waypoint, beacon, battery, maps -->
<!-- S: A GPS device can help you determine your location and navigate to a specific point, but always have a backup plan in case the device fails. -->

A GPS device can help you determine your location and navigate to a specific point but always have a backup plan in case the device fails.

### Location

A GPS uses satellites to determine your current location. Ensure the device has a clear view of the sky so it receives signals. Most GPS units display your coordinates in latitude and longitude, which can be plotted on a map.

### Waypoints

A waypoint is a specific location you want to navigate to. You can enter waypoints into your GPS to guide you to your destination. Most devices allow you to enter waypoints before your trip, but you can also add them as you go. Place waypoints frequently so you can backtrack if necessary.

If you use Trail Sense, you can use the Navigation, Beacons, Paths, and Photo Maps tools to assist with navigation.

### Battery

Your GPS device may run out of battery, so carry extra batteries or a portable charger to keep it powered.

### Digital maps

If your GPS supports digital maps, download maps of your area in advance to navigate even if you lose the signal.

## Compass
<!-- K: compass, bearing, declination, direction, north, south, east, west, orient, craft -->
<!-- S: A compass helps you determine direction. Be sure to set the same declination as your map. -->

A compass helps you determine direction and is essential for navigation, especially with a map.

### Bearings

A bearing is the direction you must travel to reach a specific point. You can determine a bearing by aligning the compass needle with the desired direction on the compass housing. Once you have the bearing, follow it to your destination. Pick a prominent feature in the distance to navigate toward, avoiding the need for constant compass checks.

### Back bearings

A back bearing is the opposite direction of your current bearing. To calculate a back bearing, if your bearing is less than 180 degrees, add 180. If it's more than 180, subtract 180.

### Declination

Declination is the difference between true north and magnetic north. Adjust your compass for declination when navigating with a map. Some compasses have an adjustable declination ring; otherwise, you must calculate it manually. Most maps list declination in the legend and are oriented to true north.

## Map
<!-- K: map, location, scale, topographic, orientation, triangulate -->
<!-- S: You can use a map to navigate once you learn how to read it. Be sure it is up to date. -->

A map is a key tool for navigation, especially when paired with a compass.

### Orientation

You can orient a map to point north using a compass:
1. Place the compass on the map with the direction of travel arrow pointing toward the top of the map.
2. Rotate the map and compass together until the compass points north.

![](file:///android_asset/survival_guide/93.webp)

### Determining location

To determine your location on a map, identify prominent features around you and match them to the map. Use a compass to determine your direction and align the map accordingly.

To triangulate your location:
1. Orient the map to point north using your compass.
2. Identify and mark two prominent features around you on the map.
3. Measure the bearing to each feature using your compass.
4. Draw lines from each feature in the direction of the bearing on the map.
5. The point where the lines intersect is your location.

### Scale

Maps are drawn to scale, allowing you to determine distances between points. A bar on the map indicates the scale. You can measure distances using a ruler, string, or finger.

![](file:///android_asset/survival_guide/104.webp)

### Topographic maps

Topographic maps show elevation changes and terrain features, making them helpful in navigating mountainous or hilly areas. Contour lines indicate elevation; the closer the lines are, the steeper the terrain. Elevation markers on contour lines help identify peaks and valleys.

![](file:///android_asset/survival_guide/95.webp)

Typical map colors include:
- **Black**: Human-made features like buildings and bridges.
- **Red**: Roads.
- **Green**: Vegetation.
- **White**: Lack of vegetation.
- **Brown**: Contour lines.
- **Blue**: Water.

## Advanced navigation techniques
<!-- K: sun, star, shadow, watch, north, south, east, west, polaris, big dipper, cassiopeia, southern cross, constellation, advanced, technique -->
<!-- S: You can use the sun or stars to determine direction. If you need this, it's best to stay where you are and wait for help. -->

### Sun

- **Shadow tip method**: Place a stick vertically in the ground and mark the shadow tip. After 10-15 minutes, mark the new position of the shadow tip and draw a line between the two points for an east-west line. North will be perpendicular to this line at midday.

![](file:///android_asset/survival_guide/88.webp)


- **Watch method**: Point the hour hand of an analog watch at the sun; south is roughly halfway between the hour hand and 12 o'clock in the Northern Hemisphere. In the Southern Hemisphere, point the 12 o'clock position at the sun. If on daylight saving time, use 1 o'clock instead of 12.

![](file:///android_asset/survival_guide/90.webp)

### Stars

- **Northern Hemisphere**: Identify Polaris (the North Star) using the Big Dipper and Cassiopeia as reference points. Polaris is located at the end of the Little Dipper's handle.

![](file:///android_asset/survival_guide/91.webp)


- **Southern Hemisphere**: Use the Southern Cross to determine south. Extend a line from the top and bottom stars of the Cross's long axis, continuing about 4.5 times the distance between these stars toward the horizon to approximate the South Pole.

![](file:///android_asset/survival_guide/92.webp)

## Craft: Compass
<!-- K: compass, needle, magnet, north, south, east, west, direction, craft -->
<!-- S: You can make a compass using a needle, knife, and a leaf. -->

**Resources**
- Needle
- Knife
- Leaf or bottle cap
- Water

**Instructions**
1. Magnetize the needle by stroking it with the knife in one direction (to avoid dulling the blade, use the back of the knife). Stroke at least 50 times.
2. Place the needle on the leaf/cap and float it in water. The needle will slowly align to the north-south axis. Ensure no currents or wind could affect the needle.