<!-- K: water, thirst, thirsty, drink -->
<!-- S: Stay hydrated and purify water. -->

This chapter covers how to find and purify water.

## Be prepared
<!-- K: prepare, gear, knowledge, skill, container, filter, sheet, tarp, tablet -->
<!-- S: Bring extra water, a water container, and purification method. Learn how to locate water sources and purify water. -->

### Gear

**Necessities**:
- Water (enough for the duration of your trip, plus a bit extra).
  - Bring a water purification method for longer trips and plan your route to include water sources.
- Water containers (ensure you have a container that you can boil water in).

**Optional**:
- Water purification method (tablets or filter).
- Cooking pot or container.
- Clear plastic sheet/tarp.

### Knowledge and skills
Start by learning how to do the following:
- Plan your water needs for the trip.
- Locate water sources.
- Purify water by boiling.

Once you have mastered these skills, you should learn how to do the following:
- Purify water using chemical treatment or filtration.
- Collect water from plants and other sources.
- Collect water using a solar still.
- Boil water using hot rocks.
- Desalinate water.

## Hydration essentials
<!-- K: hydration, essential, daily, dehydration -->
<!-- S: Drink at least 2 to 3 quarts/liters of water daily. Recognize the signs of dehydration. -->

When hiking, conserving energy while maintaining hydration is vital. Here are some general rules:

- Choose running water when possible.
- Assume surface water is contaminated; always purify it.
- Avoid the following:
  - Consuming snow without melting it
  - Urine
  - Alcohol
  - Saltwater
  - Stagnant water

### Daily water needs

At 70°F (20°C), a hiker needs around 2 to 3 quarts/liters of water daily. This amount increases with physical activity and exposure to higher temperatures.

### Dehydration

Dehydration occurs when the body loses more fluids than it takes in. Symptoms include:

- Thirst.
- Dry mouth and throat.
- Fatigue.
- Dizziness.
- Dark urine.
- Reduced urine output.
- Dry skin.
- Headache.
- Confusion.

## Finding water
<!-- K: find, source, collect, plant, solar-still, solar, still, dew, rain, river, groundwater, sea, ice, bamboo, coconut, dig, hole, snow, rainwater, desert, beach, ocean, salt, transpiration -->
<!-- S: Find water from streams, snow, rain, dew, or groundwater. Purify all water before drinking. -->

### Common water sources

- **Rainwater**: Rainwater collected directly in containers does not need purification. However, it should be purified if it has run over leaves or other surfaces.

- **Snow and ice**: Melt snow and ice before drinking. Avoid eating snow directly, as it can lower your core body temperature. Melted snow requires purification.

- **Streams and rivers**: Flowing water is typically safer than stagnant water but should still be purified.

- **Dew**: Collect dew from plants or grass by wringing out a cloth or sponge.

- **Groundwater**: Dig a deep hole and allow water to seep in. Purify the water before drinking it.

### Specific environments

- **Deserts**:
  - **Groundwater**: Look for green vegetation, valleys and low areas, or dry riverbeds.

- **Beaches/sea**:
  - **Groundwater**: Dig a deep hole to allow water to seep in. This water should be purified and may need desalination.
  - **Sea water**: Sea water can be desalinated to make it drinkable.
  - **Sea ice**: It may be salty if it is gray or opaque. Crystalline ice with a bluish tint is usually safe to melt for drinking water.

### Water from plants

Certain plants can provide water when no open sources are available:

- **Green bamboo**: Shake the bamboo to check for water, then cut it to extract the water inside.
- **Water vines**: Many vines contain drinkable water. These vines are usually soft and easy to cut. Ensure the vine is identified positively before drinking, and make sure the water is clear and odorless.
- **Coconut water**: Green coconuts are best for hydration, as they contain more fluid and less oil.

### Solar stills

**Below-ground solar still**

A below-ground solar still is a simple device that uses the sun’s heat to draw moisture from the soil or plants. The moisture then condenses on a plastic sheet and can be collected in a container. You can also pour salt water into the hole to desalinate it.

1. Dig a bowl-shaped hole about 3 feet (1 meter) across and 2 feet (0.6 meters) deep. Ensure it is in direct sunlight.
2. Place a container in the center of the hole. Optionally, place plants or water around the container to increase moisture (do not place them in the container).
3. Place a plastic sheet over the hole, securing the edges with rocks or soil.
4. Place a small rock in the center of the sheet directly over the container.
5. Wait for the sun to heat the ground and evaporate moisture, which will condense on the plastic and drip into the container.

![](file:///android_asset/survival_guide/16.webp)

**Transpiration bag**

A transpiration bag is a plastic bag tied around a leafy branch to collect water.

![](file:///android_asset/survival_guide/15.webp)

1. Tie a plastic bag around a leafy branch, ensuring that the bag is airtight.
2. Wait for the sun to heat the plant, causing moisture to evaporate and condense on the bag.
3. Collect the water that has condensed inside the bag.

## Making water safe to drink
<!-- K: make, safe, purify, boil, purification, chemical, filter, filtration, treat, bacteria, virus, parasite, stagnant, technique -->
<!-- S: Always purify water before drinking. Boil water for 1 - 3 minutes, use purification tablets, or filter it. -->

Always ensure the water you collect is safe to drink. Boiling is the most reliable method, but chemical purification tablets and filters are also effective. If you cannot purify the water immediately, prioritize finding and storing water until you can treat it.

### Purification methods

- **Boiling**: Bring water to a rolling boil for at least one minute. At higher altitudes, boil for three minutes. If you do not have a single-walled metal container that can be used for boiling, then do the following:
  1. Find another container, dig a hole in the ground and line it with a waterproof material, or craft a bowl.
  2. Fill the container with water.
  3. Heat rocks in a fire and place them in the water to heat it. **Do not** use rocks that may contain moisture (such as river rocks), as they can explode. Use two sticks in a chopstick fashion to move the rocks.
  4. Replace the rocks with hot ones to keep the water boiling.
- **Chemical treatment**: Use water purification tablets or drops according to the instructions.
- **Filtration**: Use a portable water filter to remove contaminants. Some filters are rated to remove nearly all bacteria and viruses and can be used without additional purification. If you do not have a filter, you can construct one to remove sediment, but you must also purify the water through boiling or chemical treatment. A filter can be built by layering grass or small rocks, sand, and charcoal (from top to bottom) in a container with a hole at the bottom to collect the filtered water.

![](file:///android_asset/survival_guide/19.webp)

### Hazards
- **Microorganisms**: Water may contain bacteria, viruses, and parasites that can cause illness. Boiling water kills most microorganisms, but some may require additional treatment. Microorganisms are more likely to be present in stagnant water.
- **Chemicals**: Water may contain chemicals from industrial or agricultural runoff. Purification methods may not remove all chemical contaminants.

## Craft: Bowl
<!-- K: bowl, cook, store, container -->
<!-- S: You can make a bowl from a small log by burning a bowl shape into it using hot coals. -->

A wooden bowl can be used to boil water using hot rocks.

**Resources**
- A small log (not decayed)
- Hot coals

**Instructions**
1. Cut or obtain a small log.
2. Place hot coals into the log using makeshift tongs.
3. Let the coals burn out.
4. Scrape out the charred wood with a stick or rock.
5. Repeat the process until you have a bowl.

## Craft: Tongs
<!-- K: tongs, craft -->
<!-- S: You can make tongs from green wood. -->

You can use tongs to move around hot coals or rocks without getting burned.

**Resources**
- Green wood

**Instructions**
1. Cut a length of green wood.
2. Split the wood down the middle to create a flat surface.
3. Optionally, carve a small notch in the stick's center to allow it to bend more easily.
4. Bend the wood in half to create tongs.